@@ -1,5 +1,10 @@
-from cppimport.config import set_quiet, force_rebuild, file_exts,\
-    turn_off_strict_prototypes, set_rtld_flags
+from cppimport.config import (
+    set_quiet,
+    force_rebuild,
+    file_exts,
+    turn_off_strict_prototypes,
+    set_rtld_flags,
+)
 from cppimport.importer import imp, imp_from_filepath, build
 from cppimport.templating import setup_pybind11
 from cppimport.importer import imp as cppimport
