@@ -16,6 +16,7 @@ if sys.version_info[0] == 2:
 else:
     import io
 
+
 @contextlib.contextmanager
 def stdchannel_redirected(stdchannel):
     """
@@ -30,6 +31,7 @@ def stdchannel_redirected(stdchannel):
     finally:
         setattr(sys, stdchannel, old)
 
+
 # Subclass setuptools Extension to add a parameter specifying where the shared
 # library should be placed after being compiled
 class ImportCppExt(setuptools.Extension):
@@ -37,6 +39,7 @@ class ImportCppExt(setuptools.Extension):
         self.libdest = libdest
         setuptools.Extension.__init__(self, *args, **kwargs)
 
+
 # Subclass setuptools build_ext to put the compiled shared library in the
 # appropriate place in the source tree.
 class BuildImportCppExt(setuptools.command.build_ext.build_ext):
@@ -48,15 +51,23 @@ class BuildImportCppExt(setuptools.command.build_ext.build_ext):
             dest_filename = os.path.join(ext.libdest, os.path.basename(filename))
 
             distutils.file_util.copy_file(
-                src_filename, dest_filename,
-                verbose = self.verbose, dry_run = self.dry_run
+                src_filename, dest_filename, verbose=self.verbose, dry_run=self.dry_run
             )
 
+
 # Patch for parallel compilation with distutils
-# From: http://stackoverflow.com/questions/11013851/speeding-up-build-process-with-distutils
-def parallel_compile(self, sources, output_dir = None, macros = None,
-        include_dirs = None, debug = 0, extra_preargs = None, extra_postargs = None,
-        depends = None):
+# From: http://stackoverflow.com/questions/11013851/speeding-up-build-process-with-distutils # noqa: E501
+def parallel_compile(
+    self,
+    sources,
+    output_dir=None,
+    macros=None,
+    include_dirs=None,
+    debug=0,
+    extra_preargs=None,
+    extra_postargs=None,
+    depends=None,
+):
 
     # these lines are copied directly from distutils.ccompiler.CCompiler
     macros, objects, extra_postargs, pp_opts, build = self._setup_compile(
@@ -70,6 +81,7 @@ def parallel_compile(self, sources, output_dir = None, macros = None,
     try:
         import multiprocessing
         import multiprocessing.pool
+
         N = multiprocessing.cpu_count()
     except (ImportError, NotImplementedError):
         pass
@@ -86,68 +98,66 @@ def parallel_compile(self, sources, output_dir = None, macros = None,
         # print("took " + str(end - start) + " to compile " + str(obj))
 
     # imap is evaluated on demand, converting to list() forces execution
-    list(multiprocessing.pool.ThreadPool(N).imap(_single_compile,objects))
+    list(multiprocessing.pool.ThreadPool(N).imap(_single_compile, objects))
     return objects
 
+
 def build_module(module_data):
     build_path = tempfile.mkdtemp()
 
-    full_module_name = module_data['fullname']
-    filepath = module_data['filepath']
-    cfg = module_data['cfg']
+    full_module_name = module_data["fullname"]
+    filepath = module_data["filepath"]
+    cfg = module_data["cfg"]
 
-    module_data['abs_include_dirs'] = [
-        make_absolute(module_data['filedirname'], d)
-        for d in cfg.get('include_dirs', [])
+    module_data["abs_include_dirs"] = [
+        make_absolute(module_data["filedirname"], d)
+        for d in cfg.get("include_dirs", [])
     ] + [os.path.dirname(filepath)]
-    module_data['abs_library_dirs'] = [
-        make_absolute(module_data['filedirname'], d)
-        for d in cfg.get('library_dirs', [])
+    module_data["abs_library_dirs"] = [
+        make_absolute(module_data["filedirname"], d)
+        for d in cfg.get("library_dirs", [])
     ]
-    module_data['dependency_dirs'] = (
-        module_data['abs_include_dirs'] + [module_data['filedirname']]
-    )
-    module_data['extra_source_filepaths'] = [
-        make_absolute(module_data['filedirname'], s)
-        for s in cfg.get('sources', [])
+    module_data["dependency_dirs"] = module_data["abs_include_dirs"] + [
+        module_data["filedirname"]
+    ]
+    module_data["extra_source_filepaths"] = [
+        make_absolute(module_data["filedirname"], s) for s in cfg.get("sources", [])
     ]
 
     ext = ImportCppExt(
         os.path.dirname(filepath),
         full_module_name,
-        language = 'c++',
-        sources = (
-            module_data['extra_source_filepaths'] +
-            [module_data['rendered_src_filepath']]
+        language="c++",
+        sources=(
+            module_data["extra_source_filepaths"]
+            + [module_data["rendered_src_filepath"]]
         ),
-        include_dirs = module_data['abs_include_dirs'],
-        extra_compile_args = cfg.get('extra_compile_args', []),
-        extra_link_args = cfg.get('extra_link_args', []),
-        library_dirs = module_data['abs_library_dirs'],
-        libraries = cfg.get('libraries', [])
+        include_dirs=module_data["abs_include_dirs"],
+        extra_compile_args=cfg.get("extra_compile_args", []),
+        extra_link_args=cfg.get("extra_link_args", []),
+        library_dirs=module_data["abs_library_dirs"],
+        libraries=cfg.get("libraries", []),
     )
 
-    args = ['build_ext', '--inplace']
-    args.append('--build-temp=' + build_path)
-    args.append('--build-lib=' + build_path)
+    args = ["build_ext", "--inplace"]
+    args.append("--build-temp=" + build_path)
+    args.append("--build-lib=" + build_path)
 
     if cppimport.config.quiet:
-        args.append('-q')
+        args.append("-q")
     else:
-        args.append('-v')
+        args.append("-v")
 
     setuptools_args = dict(
-        name = full_module_name,
-        ext_modules = [ext],
-        script_args = args,
-        cmdclass = {
-            'build_ext': BuildImportCppExt
-        }
+        name=full_module_name,
+        ext_modules=[ext],
+        script_args=args,
+        cmdclass={"build_ext": BuildImportCppExt},
     )
 
     # Monkey patch in the parallel compiler if requested.
     py33orgreater = sys.version_info[0] >= 3 and sys.version_info[1] >= 3
-    parallelize = cfg.get('parallel') and py33orgreater
+    parallelize = cfg.get("parallel") and py33orgreater
     if parallelize:
         old_compile = distutils.ccompiler.CCompiler.compile
         distutils.ccompiler.CCompiler.compile = parallel_compile
