@@ -11,13 +11,12 @@ int add(int i, int j) {
     return i + j;
 }
 
-PYBIND11_PLUGIN(mymodule) {
-    pybind11::module m("mymodule", "auto-compiled c++ extension");
+PYBIND11_MODULE(mymodule, m) {
     m.def("add", &add);
 #ifdef THING_DEFINED
+    #pragma message "stuff"
     py::class_<Thing>(m, "Thing")
         .def(py::init<>())
         .def("cheer", &Thing::cheer);
 #endif
-    return m.ptr();
 }
